% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read_ecoregions.R
\name{read_ecoregions}
\alias{read_ecoregions}
\title{Return the \code{ecoregions} data source as an \code{sf} object}
\usage{
read_ecoregions(
  file = file.path(fileman_up("n2khab_data"), "10_raw/ecoregions")
)
}
\arguments{
\item{file}{The absolute or relative file path of the data source.
The default follows the data management advice in the
vignette on data storage (run \code{vignette("v020_datastorage")}).
It uses the first \code{n2khab_data} folder that is found when
sequentially climbing up 0 to 10 levels in the file system hierarchy,
starting from the working directory.}
}
\value{
A Simple feature collection of geometry type \code{MULTIPOLYGON}.
}
\description{
Returns the raw data source \code{ecoregions}, with unique polygon
identifiers \code{polygon_code} and \code{polygon_id}.
Multiple polygons can have the same \code{region_name}.
The coordinate reference system is 'Belge 72 / Belgian Lambert 72'
(EPSG-code \href{https://epsg.io/31370}{31370}).
}
\details{
Original columns of the raw data source were mapped as:
\itemize{
\item \code{CODE} -> \code{polygon_code}
\item \code{NR} -> \code{polygon_id}
\item \code{REGIO} -> \code{region_name}
\item \code{DISTRICT} -> \code{district_name}
}

Apart from the label, there is no complementary information between
\code{polygon_code} and \code{polygon_id}.
}
\examples{
\dontrun{
ecoregions <- read_ecoregions()
ecoregions
}

}
