% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/read_habitatdata.R
\name{read_watersurfaces}
\alias{read_watersurfaces}
\title{Return the data source \code{watersurfaces} as an \code{sf} polygon layer}
\usage{
read_watersurfaces(
  file = file.path(fileman_up("n2khab_data"), "10_raw/watersurfaces"),
  extended = FALSE,
  version = "watersurfaces_v1.0"
)
}
\arguments{
\item{file}{The absolute or relative file path of the data source.
The default follows the data management advice in the
vignette on data storage (run \code{vignette("v020_datastorage")}).
It uses the first \code{n2khab_data} folder that is found when
sequentially climbing up 0 to 10 levels in the file system hierarchy,
starting from the working directory.}

\item{extended}{Logical.
Should names or explanations of codes be added as extra
variables in the result?
Currently only applies to \code{wfd_type}; if \code{TRUE}, a variable
\code{wfd_type_name} is added.
Defaults to \code{FALSE}.}

\item{version}{Version ID of the data source.
Defaults to the latest available version defined by the package.}
}
\value{
A Simple feature collection of
type \code{POLYGON}, sorted by \code{polygon_id}, with the following
variables (not mentioning extra 'name' variables for
\code{extended = TRUE}):
\itemize{
  \item \code{polygon_id}: code of the polygon;
  \item \code{wfd_code}: optional; Flemish code of the water body with
  regard to the Water Framework Directive (WFD);
  \item \code{hyla_code}: optional; code of the watersurface according to the
  Flemish working group 'Hyla', a working group on amphibians & reptiles;
  \item \code{name}: name of the watersurface;
  \item \code{area_name}: name of the area;
  \item \code{wfd_type}: type code according to the Flemish WFD typology
  (Denys, 2009);
  \item \code{wfd_type_certain}: Logical.
  Is there high confidence about the \code{wfd_type} determination?
  \item \code{depth_class}: class of water depth;
  \item \code{connectivity}: connectivity class;
  \item \code{usage}: usage class.
}
}
\description{
Returns the raw data source \code{watersurfaces} (Packet et al., 2018)
as a standardized \code{sf} polygon layer
(tidyverse-styled, internationalized) in the Belgian Lambert 72 CRS
(EPSG-code \href{https://epsg.io/31370}{31370}).
}
\details{
See Packet et al. (2018) for an elaborate explanation of the data source
and its attributes.
}
\examples{
\dontrun{
# This example supposes that your working directory or a directory up to 10
# levels above has the 'n2khab_data' folder AND that the 'watersurfaces'
# data source is present in the default subdirectory.
# In all other cases, this example won't work but at least you can
# consider what to do.

ws <- read_watersurfaces()
ws
summary(ws)

ws2 <- read_watersurfaces(extended = TRUE)
ws2
}

}
\references{
\itemize{
\item Denys L. (2009). Een a posteriori typologie van stilstaande, zoete
wateren in Vlaanderen.
Rapporten van het Instituut voor Natuur- en Bosonderzoek INBO.R.2009.34.
Instituut voor Natuur- en Bosonderzoek, Brussel.
\item Packet J., Scheers K., Smeekens V., Leyssen A., Wils C. & Denys L.
(2018).
Watervlakken versie 1.0: polygonenkaart van stilstaand water in Vlaanderen.
Een nieuw instrument voor onderzoek, water-, milieu- en natuurbeleid.
Rapporten van het Instituut voor Natuur- en Bosonderzoek 2018 (14).
Instituut voor Natuur- en Bosonderzoek, Brussel.
\doi{10.21436/inbor.14178464}.
}
}
\seealso{
Other functions involved in processing the 'watersurfaces' data source: 
\code{\link{read_watersurfaces_hab}()}
}
\concept{functions involved in processing the 'watersurfaces' data source}
\concept{functions returning important environmental data sets}
